@@ -313,7 +313,7 @@ class CommandLineParser(object):
                 else:
                     self.parser.print_help()
                 self.parser.exit(2)
-            elif "-v" in sys.argv:
+            elif "-v" in sys.argv or "--ver" in sys.argv:
                 print version()
                 self.parser.exit(0)
             else:
